# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-08-16 03:41
from __future__ import unicode_literals

from django.db import migrations, models
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('paypal', '0003_paypaltransaction_user'),
    ]

    operations = [
        migrations.AddField(
            model_name='paypaltransaction',
            name='uid',
            field=models.CharField(default=uuid.uuid4, max_length=36, unique=True),
        ),
    ]
